@@ -158,6 +158,9 @@ INTERNALERROR_FTPERROR = 'InternalError.FtpError'
 # Exceptional HTTP request
 INTERNALERROR_HTTPERROR = 'InternalError.HttpError'
 
+# Import failed
+INTERNALERROR_IMPORTERROR = 'InternalError.ImportError'
+
 # Internal service error
 INTERNALERROR_INNERCOMMONERROR = 'InternalError.InnerCommonError'
 
